# dev_tools_tests

Developer tools testing repository

Repositório para testes e aprendisagem de ferramentas que auxiliam o desenvolvedor.

[![Build Status](https://app.travis-ci.com/lucasfmerino/dev_tools_tests.svg?branch=main)](https://app.travis-ci.com/lucasfmerino/dev_tools_tests)
[![Updates](https://pyup.io/repos/github/lucasfmerino/dev_tools_tests/shield.svg)](https://pyup.io/repos/github/lucasfmerino/dev_tools_tests/)
[![Python 3](https://pyup.io/repos/github/lucasfmerino/dev_tools_tests/python-3-shield.svg)](https://pyup.io/repos/github/lucasfmerino/dev_tools_tests/)

---

Tópicos de estudo:

    1. Git
    2. Virtualenv
    3. Pip
    4. Rrquests
    5. Flake8
    6. Travis CI
    7. Publicação de pacote PyPi
    8. Pytest
    9. Codecov

---

Instalação (Windows)

```Console
python -m venv venv
venv\Scripts\activate
pip install -r requirements-dev.txt
```

Conferir Qualidade

```Console
flake8

```

---

<h4 align="center"> 
	🚧  Repositório 🚀 Em construção...  🚧
</h4>
